@@ -153,5 +153,6 @@ def start_gateway(descriptor: FileDescriptor, loop: BaseEventLoop, port: int = 7
               http_path = getattr(http_rule, supported_method)
               if http_path != '':
                 app.add_route(http_path, route=request_handler, methods=[supported_method])
-  loop.create_task(serve(app, config))
+  server = serve(app, config)
+  loop.create_task(server)
   logging.info(f'started gateway on port {port}')
\ No newline at end of file
